@@ -75,7 +75,11 @@ class BasePublisher(object):
         if handler is None:
             raise http.Http404
         # Do we need to pass any of this?
-        return handler(request, action=action, object_id=object_id, **kwargs)
+        try:
+            return handler(request, action=action, object_id=object_id, **kwargs)
+        except http.BaseHttpResponse as response:
+            return response
+
 
 class Publisher(engine.JsonEngine, BasePublisher):
     '''Default API-style publisher'''
@@ -233,5 +237,5 @@ class ModelFormMixin(object):
         obj = self.get_object(object_id)
         # XXX Some sort of verification?
         obj.delete()
-        return http.HttpResponseNoContent()
+        return http.NoContent()
 
